# Changelog

<!--next-version-placeholder-->

## v0.1.131 (2021-10-10)
### Feature
* **seatconnect:** Bugfixing ([#39](https://github.com/dominikkarall/fhempy/issues/39)) ([`a5996f5`](https://github.com/dominikkarall/fhempy/commit/a5996f557c12ce4a7390faee31d0cbaeb05dbe71))
* **fhempy:** Add new devices to room/group ([`c197110`](https://github.com/dominikkarall/fhempy/commit/c197110a26df50acea79ae9abdac7832ac0182f6))

### Fix
* **tuya_cloud:** Better error handling ([`056ab5c`](https://github.com/dominikkarall/fhempy/commit/056ab5c4c5583f490c17b7d007b347f1d08ca2a4))
* **xiaomi_gateway3:** Fix attr usage ([`eb1f4b1`](https://github.com/dominikkarall/fhempy/commit/eb1f4b180944d28697fd49a0c4b7be5730d9e326))
* **fhempy:** Flake8 fixes ([`519658c`](https://github.com/dominikkarall/fhempy/commit/519658ccbad6ebc9c8eb27f4dc9025913f7fdb4f))

## v0.1.130 (2021-10-08)
### Feature
* **seatconnect:** Integration of Timer Schedule for Climatisation ([#38](https://github.com/dominikkarall/fhempy/issues/38)) ([`f3a130d`](https://github.com/dominikkarall/fhempy/commit/f3a130d92948ce9eaa5cb65c61ce7e68c7049251))

## v0.1.129 (2021-10-08)
### Fix
* **xiaomi_gateway3:** Small fixes ([`d96bbc8`](https://github.com/dominikkarall/fhempy/commit/d96bbc849c24fb275e8bc3e3f3b0095f81464ccc))

## v0.1.128 (2021-10-07)
### Fix
* **xiaomi_gateway3:** Fix gateway device ([`24f0b13`](https://github.com/dominikkarall/fhempy/commit/24f0b13aa29f557ec3ccee32e78c18fc03a619ef))

## v0.1.127 (2021-10-07)
### Feature
* **xiaomi_gateway3:** Update xg3 library ([`62352da`](https://github.com/dominikkarall/fhempy/commit/62352da7581f1f338d34078ebfc2822fd38e217a))

### Fix
* **fhempy:** Better error handling ([`5910b6a`](https://github.com/dominikkarall/fhempy/commit/5910b6ae1fe3a6ea2e2cb97cdcf45ba782a25024))

## v0.1.126 (2021-09-30)
### Fix
* **fhempy:** Update requirements ([`f327a5a`](https://github.com/dominikkarall/fhempy/commit/f327a5a5e5abd3393c336743a376618d5136176a))

## v0.1.125 (2021-09-30)
### Fix
* **tuya_cloud:** Fix rgb readings ([`5257ff2`](https://github.com/dominikkarall/fhempy/commit/5257ff2428219e75767b4f756734d7dbf1982bbf))
* **meross:** Add usage ([`ccd7a4c`](https://github.com/dominikkarall/fhempy/commit/ccd7a4cd9b84573fbc472a024c0e1854fb509038))

## v0.1.124 (2021-09-29)
### Feature
* **meross:** Support meross on/off ([`d08c927`](https://github.com/dominikkarall/fhempy/commit/d08c927361771164d8dc7665e0687fdc3420e777))
* **fhempy:** Add gen_fhemdev_name fct ([`6cf9829`](https://github.com/dominikkarall/fhempy/commit/6cf9829124d6c3f759360b176be34510b319b7c7))

### Fix
* **fhempy:** Add exception handling ([`bcaaf97`](https://github.com/dominikkarall/fhempy/commit/bcaaf970f4b0f2e239bba52fe7c136f92c95218c))
* **tuya_cloud:** Handle stop() exceptions ([`8bb081a`](https://github.com/dominikkarall/fhempy/commit/8bb081aa46f55a98a3900fc062b77fdd8369c16f))

## v0.1.123 (2021-09-28)
### Fix
* **tuya_cloud:** Fix devnames with dashes ([`54e2f7c`](https://github.com/dominikkarall/fhempy/commit/54e2f7cb1de5f8bc844eb18f4332fbbbb8c7151d))

## v0.1.122 (2021-09-28)
### Feature
* **seatconnect:** First Version of seatconnect ([#35](https://github.com/dominikkarall/fhempy/issues/35)) ([`124f715`](https://github.com/dominikkarall/fhempy/commit/124f71588f3bd54e20118baf37029760809cdfe8))

## v0.1.121 (2021-09-28)


## v0.1.120 (2021-09-22)
### Fix
* **fhempy:** Handle zeroconf exceptions ([`eebf78f`](https://github.com/dominikkarall/fhempy/commit/eebf78f761909ded5228cb0e32e99a89bd7cbeab))

## v0.1.119 (2021-09-20)
### Fix
* **fhempy:** Add debug output ([`3b09a35`](https://github.com/dominikkarall/fhempy/commit/3b09a351db8851dfc5b34b684768d093e1a8ba45))

## v0.1.118 (2021-09-19)
### Fix
* **tuya_cloud:** Support devices with umlauts ([`df937dc`](https://github.com/dominikkarall/fhempy/commit/df937dc0c9298ac0dea0a795510ea14330b0b2d9))
* **discover_mdns:** Use async zeroconf ([`6ad6445`](https://github.com/dominikkarall/fhempy/commit/6ad6445e202e5cbe0a486b2701a775b6b32d599d))

## v0.1.117 (2021-09-08)
### Fix
* **fhempy:** Fix release script ([`de82f89`](https://github.com/dominikkarall/fhempy/commit/de82f891c300feda26bc35168119293a520991f6))

## v0.1.116 (2021-09-07)
### Feature
* **skodaconnect:** Add honk and flash support ([`623c3d3`](https://github.com/dominikkarall/fhempy/commit/623c3d3bef608edfa0ed5c00f157e8f90fcc908d))

### Fix
* **skodaconnect:** Update lib to 1.1.4 ([`192c4f3`](https://github.com/dominikkarall/fhempy/commit/192c4f3ac70b1b2ee33298f8d23d3aba7b025e79))
* **skodaconnect:** Update lib to 1.1.3 ([`ae47357`](https://github.com/dominikkarall/fhempy/commit/ae4735782c9d15a7a408de965b27bcdb422c1d23))

## v0.1.115 (2021-09-05)
### Fix
* **skodaconnect:** Update lib to 1.1.2 ([`a012022`](https://github.com/dominikkarall/fhempy/commit/a012022ae7ccb7c746df448d0b99975251fa25ce))

## v0.1.114 (2021-09-05)
### Fix
* **erelax_vaillant:** Set endtime 0 if not active ([`9103634`](https://github.com/dominikkarall/fhempy/commit/91036349b24ded901051833a79aecf920af23f0f))

## v0.1.113 (2021-09-05)
### Fix
* **erelax_vaillant:** Fix readings again ([`4fcb9d2`](https://github.com/dominikkarall/fhempy/commit/4fcb9d24c6deadbc1b622dc7dd9df4d26a6be645))

## v0.1.112 (2021-09-05)
### Fix
* **erelax_vaillant:** Fix away/manual readings ([`ab0cc0c`](https://github.com/dominikkarall/fhempy/commit/ab0cc0ca69a24b66dbef4ff7343f11297588425f))

## v0.1.111 (2021-09-05)
### Fix
* **erelax_vaillant:** Fix away/manual readings ([`31dfb46`](https://github.com/dominikkarall/fhempy/commit/31dfb464fc2a79121cbe0ea89a2e890954244f5c))

## v0.1.110 (2021-09-05)
### Feature
* **erelax_vaillant:** Add away, manual readings ([`2e49418`](https://github.com/dominikkarall/fhempy/commit/2e494188b5e5c84603e2994bf4cb977b33b4c586))

## v0.1.109 (2021-08-31)
### Fix
* **tuya_cloud:** Fix reading updates ([`572c088`](https://github.com/dominikkarall/fhempy/commit/572c0880747a8535f9092f87cc12ee91e0910f6c))

## v0.1.108 (2021-08-30)
### Fix
* **tuya_cloud:** Fix startup issues ([`a9c2e99`](https://github.com/dominikkarall/fhempy/commit/a9c2e99db2fd0730b95bb3a1dab5e8f853753ec1))
* **fhempy:** Fix github sec alert ([`6be1403`](https://github.com/dominikkarall/fhempy/commit/6be14039106babb653faa048336827e1719533bb))

## v0.1.107 (2021-08-30)
### Fix
* **fhempy:** Update aiohttp library ([`f00540a`](https://github.com/dominikkarall/fhempy/commit/f00540abbc6daf6c8b8ba81772c3bef6769499fd))
* **skodaconnect:** Update library to 1.0.52 ([`f14583e`](https://github.com/dominikkarall/fhempy/commit/f14583ef3b6beb5032064aeb016fe0966238cbe8))
* **dlna_dmr:** Fix get_local_ip ([`e12f602`](https://github.com/dominikkarall/fhempy/commit/e12f60233cb5bd703d091a47bc21a3261d926331))

## v0.1.106 (2021-08-29)
### Fix
* **tests:** Fix ring test ([`9098245`](https://github.com/dominikkarall/fhempy/commit/90982456484aec502ceeefe08c3a4be9e0ff9db4))

## v0.1.105 (2021-08-29)
### Feature
* **upnp:** Update upnp library ([`f2c5120`](https://github.com/dominikkarall/fhempy/commit/f2c512079c665e8dd84c1efa288b08873cc98fed))

### Fix
* **fhempy:** Fix zeroconf exception ([`7ad2e73`](https://github.com/dominikkarall/fhempy/commit/7ad2e73c4140fa99ccac5a9a28fcc094fa890a61))

## v0.1.104 (2021-08-28)
### Feature
* **googlecast:** Update libraries ([#25](https://github.com/dominikkarall/fhempy/issues/25)) ([`856eeac`](https://github.com/dominikkarall/fhempy/commit/856eeac940659974458b323c6aa2d266a576040d))
* **ring:** Update library to 0.7.1 ([#24](https://github.com/dominikkarall/fhempy/issues/24)) ([`9aa2360`](https://github.com/dominikkarall/fhempy/commit/9aa236079a81f483294be41e0a84a167b2ae5bed))

## v0.1.103 (2021-08-28)
### Fix
* **fhempy:** Update requirements ([`02de53d`](https://github.com/dominikkarall/fhempy/commit/02de53de90b910c9a00a16267961869e5848ee41))

## v0.1.102 (2021-08-28)
### Feature
* **fhempy:** Update to asynczeroconf ([`7b319e3`](https://github.com/dominikkarall/fhempy/commit/7b319e347601634894c458c7ac2b3782b99dee5e))

### Fix
* **fhempy:** Better error handling ([`e4f2ba2`](https://github.com/dominikkarall/fhempy/commit/e4f2ba2a2d1c46b9bc767119ff4f4519e61ce724))
* **fhempy:** Rename to fhempy ([`38121ce`](https://github.com/dominikkarall/fhempy/commit/38121ce24260cf4dfd8291901c760008d6ee48e8))

## v0.1.101 (2021-08-27)
### Fix
* **esphome:** Fix deprecation warning ([`49af229`](https://github.com/dominikkarall/fhempy/commit/49af2290a0527370857292c23bc51b9a9a522b2f))
* **fhempy:** Fix NO RESPONSE msgs ([`3413202`](https://github.com/dominikkarall/fhempy/commit/341320259b85f2d545c62cf898c060025181db5a))
* **fhempy:** Fix log ([`d3d11c4`](https://github.com/dominikkarall/fhempy/commit/d3d11c440c107fa21a871e331c7834add1e820ad))

## v0.1.100 (2021-08-27)
### Fix
* **skodaconnect:** Update library ([`dc2035b`](https://github.com/dominikkarall/fhempy/commit/dc2035bb80810343eae441279ce52d1d1eddbbea))
* **tuya_cloud:** Update tuya lib ([`8059a68`](https://github.com/dominikkarall/fhempy/commit/8059a68023c693e0035bd163cdb6a393a53a63d4))

## v0.1.99 (2021-08-27)
### Fix
* **tuya_cloud:** Fix colour_data again ([`fd37524`](https://github.com/dominikkarall/fhempy/commit/fd37524f94bc30667b75849b1933e223d92df361))

## v0.1.98 (2021-08-27)
### Fix
* **tuya_cloud:** Fix again colour_data ([`82998c7`](https://github.com/dominikkarall/fhempy/commit/82998c757357c9c9aee4fbc0b7c83ac8d9170cfb))

## v0.1.97 (2021-08-26)
### Fix
* **tuya_cloud:** Handle exception on mqtt stop ([`de40876`](https://github.com/dominikkarall/fhempy/commit/de4087678f95429e9c86bf4ee3cd767f6836a326))
* **tuya_cloud:** Fix colour_data ([`c87c985`](https://github.com/dominikkarall/fhempy/commit/c87c9857c67b164cca75f87f5ff2b28fc284b5ac))
* **fhempy:** Add use Color ([`89c8264`](https://github.com/dominikkarall/fhempy/commit/89c8264adab1a2d788d73c0e1caaa438aa7af850))

## v0.1.96 (2021-08-26)
### Fix
* **tuya_cloud:** Fix colour_data ([`b46189c`](https://github.com/dominikkarall/fhempy/commit/b46189c60d0f0e58797b2dd0e8024ddfd97a66f8))

## v0.1.95 (2021-08-26)
### Feature
* **tuya_cloud:** Support colorpicker ([`fbef95d`](https://github.com/dominikkarall/fhempy/commit/fbef95d49466342270833adb428b466312ef372c))

## v0.1.94 (2021-08-25)
### Fix
* **mitemp:** Latest mitemp lib not working ([`9e2dcfc`](https://github.com/dominikkarall/fhempy/commit/9e2dcfc092d9102248bc8b4ef28c340505d5fc46))

## v0.1.93 (2021-08-25)
### Fix
* **tuya_cloud:** Fix reset_reading ([`48410ec`](https://github.com/dominikkarall/fhempy/commit/48410ecfbe89b1c0310e83c4676c9407900551ad))
* **mitemp:** Update library ([`6919917`](https://github.com/dominikkarall/fhempy/commit/691991759cbc9909ede6aa44b23c030d9350d234))

## v0.1.92 (2021-08-25)
### Feature
* **tuya_cloud:** Set state for some devices ([`de4f07a`](https://github.com/dominikkarall/fhempy/commit/de4f07a9d47c19c536464670081ef5f80f3789cf))
* **miflora:** Change conductivity to fertility ([`6d27f47`](https://github.com/dominikkarall/fhempy/commit/6d27f47f196c889c0c80cbaf0f5fcf2af0c2ae51))
* **tuya_cloud:** Use switch_led for state ([`a5f7e65`](https://github.com/dominikkarall/fhempy/commit/a5f7e659af1ba32ae9f15567f061122a6312c22c))

### Fix
* **fhempy:** Fix room for fhempy log ([`9662148`](https://github.com/dominikkarall/fhempy/commit/966214849c577e085dd3e796bb4ba71a7367a721))

## v0.1.91 (2021-08-24)
### Fix
* **tuya_cloud:** Fix set_json ([`246584f`](https://github.com/dominikkarall/fhempy/commit/246584fc1fd7adc6d4743e6dc9be9c43c8a28498))
* **skodaconnect:** Fix climater with new library ([`bdc8058`](https://github.com/dominikkarall/fhempy/commit/bdc8058c2d759454e6919b16d04aa36238de1d2e))

## v0.1.90 (2021-08-23)


## v0.1.89 (2021-08-23)
### Feature
* **tuya_cloud:** Support json commands ([`fdc9170`](https://github.com/dominikkarall/fhempy/commit/fdc9170129fb0d45298eb9d3d323169fdba857a0))

### Fix
* **skodaconnect:** Fix climatisation ([`1870427`](https://github.com/dominikkarall/fhempy/commit/18704278f393203e487899b79ca6fe2b7b065745))

## v0.1.88 (2021-08-22)
### Fix
* **skodaconnect:** Fix climatisation ([`527214f`](https://github.com/dominikkarall/fhempy/commit/527214fa5be15a7ba52b726472f1900b43262f61))

## v0.1.87 (2021-08-17)
### Fix
* **xiaomi_gateway3:** Fix reading updates ([`d8a7ff0`](https://github.com/dominikkarall/fhempy/commit/d8a7ff04545b8411c0692df3f5d42cf44f14bec8))

## v0.1.86 (2021-08-16)
### Fix
* **tuya_cloud:** Fix reading updates ([`54a1259`](https://github.com/dominikkarall/fhempy/commit/54a12595ec52bb6bb13a6619a77e26d16b161654))

## v0.1.85 (2021-08-16)
### Fix
* **skodaconnect:** Fix update readings ([#21](https://github.com/dominikkarall/fhempy/issues/21)) ([`cd0aef9`](https://github.com/dominikkarall/fhempy/commit/cd0aef9dec0350570b9b6667e356db53216e631e))

## v0.1.84 (2021-08-15)
### Fix
* **tuya_cloud:** Fix switch ([`d1d1e03`](https://github.com/dominikkarall/fhempy/commit/d1d1e03f629985175a0bae88f797f5cc49ab1b0d))

## v0.1.83 (2021-08-13)
### Fix
* **tuya_cloud:** Fix default code for state ([`deedac5`](https://github.com/dominikkarall/fhempy/commit/deedac5f4853c92d3d79b6848b89542134dfdaf0))

## v0.1.82 (2021-08-08)
### Fix
* **tuya_cloud:** Fix tuya lib version ([`9cb101e`](https://github.com/dominikkarall/fhempy/commit/9cb101e9ba9812e5060039eebb105e4f95855385))

## v0.1.81 (2021-08-07)
### Fix
* **skodaconnect:** Fix typo auxiliary ([`9455fc2`](https://github.com/dominikkarall/fhempy/commit/9455fc2b8fd66c329f4eb3e30b67e9fabd31cee6))

## v0.1.80 (2021-08-07)
### Fix
* **skodaconnect:** Fix update_interval/_readings ([`8ee0686`](https://github.com/dominikkarall/fhempy/commit/8ee0686595e22337b0f5bf8c17720ec09a3a33a8))

## v0.1.79 (2021-08-06)
### Fix
* **fhempy:** Fix zeroconf ([`bf048e3`](https://github.com/dominikkarall/fhempy/commit/bf048e322a58949eef11f305ecf09435b24ebda9))

## v0.1.78 (2021-08-06)
### Fix
* **skodaconnect:** Climatisation fix ([`8f2bc7d`](https://github.com/dominikkarall/fhempy/commit/8f2bc7da3d0767897d31269a5fba91e2c3854f0c))

## v0.1.77 (2021-08-02)
### Fix
* **tests:** Fix update test ([`b170df1`](https://github.com/dominikkarall/fhempy/commit/b170df1cfb06185c83aad5aa8a8c05aa183d89c9))
* **fhempy:** Log successfull update ([`2a3e37f`](https://github.com/dominikkarall/fhempy/commit/2a3e37f75db9b7277344e8fe0e255f31f1a59f9f))

## v0.1.76 (2021-08-02)
### Fix
* **fhempy:** Fix shutdown after update ([`3d7d556`](https://github.com/dominikkarall/fhempy/commit/3d7d5569ee5416e08ed793791a55b5d3e15531d8))

## v0.1.75 (2021-08-02)
### Fix
* **tuya_cloud:** One more fix ([`4a8dc19`](https://github.com/dominikkarall/fhempy/commit/4a8dc199c0fbb5ea99105e7ee47e0c83a0acbc96))

## v0.1.74 (2021-08-02)
### Fix
* **tuya_cloud:** Some fixes ([`357ddf1`](https://github.com/dominikkarall/fhempy/commit/357ddf1299a123e28c3b18571b64ced5da2aeac4))

## v0.1.73 (2021-08-02)
### Fix
* **tuya_cloud:** Fix readings for unsupported devs ([`8dea541`](https://github.com/dominikkarall/fhempy/commit/8dea541efce093b80eb187a051d00fc1051f55a0))

## v0.1.72 (2021-08-01)
### Fix
* **tuya_cloud:** Handle unsupported devices ([`0c224bd`](https://github.com/dominikkarall/fhempy/commit/0c224bd5d05825c6da004890574640442df6566c))

## v0.1.71 (2021-07-31)
### Fix
* **tuya_cloud:** Fix autocreation of new devices ([`80607f2`](https://github.com/dominikkarall/fhempy/commit/80607f2c566e6cf548e3eee786cc00df516e50ec))
* **xiaomi_gateway3:** Fix temp symbol ([`b033d42`](https://github.com/dominikkarall/fhempy/commit/b033d421c0634375fda99512b91e99b5dcb9e27c))

## v0.1.70 (2021-07-30)
### Feature
* **tuya_cloud:** Support all tuya devices ([`ddceb85`](https://github.com/dominikkarall/fhempy/commit/ddceb855fe6758d5884346ea93a6e84a06625c34))
* **fhempy:** Use fhempy room instead of hidden ([`ae2ffdc`](https://github.com/dominikkarall/fhempy/commit/ae2ffdc9672e467d0ae68294acb6b79b559c8a04))
* **fhempy:** Support init_done ([`c807582`](https://github.com/dominikkarall/fhempy/commit/c80758235165e50f9256cc060db2930a5b97b738))
* **erelax_vaillant:** Support home/away ([`b29edde`](https://github.com/dominikkarall/fhempy/commit/b29eddeb16eb50c86f22eceb7cd8b2277e87f718))

### Fix
* **tuya:** Fix attributes ([`1bd998e`](https://github.com/dominikkarall/fhempy/commit/1bd998e478ff6e278b889169baeb89d0493031cb))

## v0.1.69 (2021-07-27)
### Feature
* **erelax_vaillant:** Support erelax vaillant ([`0c7f12c`](https://github.com/dominikkarall/fhempy/commit/0c7f12c7f8709687cdf2d477b055c03bb3c6e38a))

## v0.1.68 (2021-07-13)
### Feature
* **tuya:** Support unknown tuya devices ([`d42d30d`](https://github.com/dominikkarall/fhempy/commit/d42d30d2f91b4266eabf13a8e0985a24dee10f32))

## v0.1.67 (2021-07-13)
### Fix
* **tuya:** Create unknown devices ([`3a57f5b`](https://github.com/dominikkarall/fhempy/commit/3a57f5bb5bbd3697ad19e8d58a0cff5da9267ad2))
* **ring:** Fix ring auth ([`ebc454d`](https://github.com/dominikkarall/fhempy/commit/ebc454d5302b3f9356b9d54efab6d76f833c5d35))

## v0.1.66 (2021-07-04)


## v0.1.65 (2021-06-25)
### Feature
* **skodaconnect:** Change vehicle.update() to connection.update(), add UpdateInterval, add UpdateReading, add ForceUpdate, add missing set_ commands, ([`1de20c3`](https://github.com/dominikkarall/fhempy/commit/1de20c34fe61541d42a1628a05b6b526aa439698))

## v0.1.64 (2021-06-23)
### Feature
* **skodaconnect:** Add skoda connect support ([`ab507e8`](https://github.com/dominikkarall/fhempy/commit/ab507e872293014fedad786bf5d85c4e82eb36a4))

## v0.1.63 (2021-06-01)


## v0.1.62 (2021-06-01)


## v0.1.61 (2021-05-23)
### Fix
* **miflora:** Fix deadlocks ([`21810f8`](https://github.com/dominikkarall/fhempy/commit/21810f8f6680186b329db31e5a6de8fc0010b0aa))
* **BindingsIo:** Fix possible 100% cpu bug ([`947a90e`](https://github.com/dominikkarall/fhempy/commit/947a90e472034186656128676ba7d16f728950b3))

## v0.1.60 (2021-05-04)
### Feature
* **mitemp2:** Test version of mitemp2 ([`31e17a4`](https://github.com/dominikkarall/fhempy/commit/31e17a4e439ab92463659c20c0e494cd33f85947))

### Fix
* **spotify:** Change auth url ([`63319ba`](https://github.com/dominikkarall/fhempy/commit/63319bad78301caae4b0273745e459969fcf308f))
* **googlecast:** Fix spotify play ([`08ea929`](https://github.com/dominikkarall/fhempy/commit/08ea929003d6966c587aed433f6fefbe70e13cdf))
* **spotify:** Fix deprecation warning ([`a852b75`](https://github.com/dominikkarall/fhempy/commit/a852b75cd13a06ae90ad8b004225fb04014b0b45))
* **spotify_connect_player:** Fix deprecation warn ([`e9bc04b`](https://github.com/dominikkarall/fhempy/commit/e9bc04bc61cf439b12e6ad4b5101ca57f1bab2e6))
* **googlecast:** Fix spotify, add speak_lang attr ([`6a81f15`](https://github.com/dominikkarall/fhempy/commit/6a81f15dbce5d2b57489b1c0cffec88fe5653c53))

## v0.1.59 (2021-04-18)
### Fix
* **ring:** Fix update_health_data ([`747a129`](https://github.com/dominikkarall/fhempy/commit/747a12996a9b2552256fe0492086150c94586e5d))

## v0.1.58 (2021-04-18)
### Feature
* **tuya:** Support miio lib 0.5.5.2 ([`88fb98b`](https://github.com/dominikkarall/fhempy/commit/88fb98bdd7e9f73bff231e64236832685e12f47b))

## v0.1.57 (2021-03-09)
### Fix
* **fhempy:** Fix possible crash on reconnect ([`d68d60b`](https://github.com/dominikkarall/fhempy/commit/d68d60bcf9f52c145ad6be221fb6a7fe7388ee03))
* **ring:** Fix battery/volume updates ([`936cc49`](https://github.com/dominikkarall/fhempy/commit/936cc495c86040d13fc34e11668daf6d32967aa1))

## v0.1.56 (2021-03-08)
### Feature
* **googlecast:** Update to pychromecast 9.1.1 ([`fdaab50`](https://github.com/dominikkarall/fhempy/commit/fdaab50f99006806464603a2ecfd2f4adf137967))

### Fix
* **ring:** Revert ring_doorbell lib to 0.6.2 ([`71b9511`](https://github.com/dominikkarall/fhempy/commit/71b9511e47751eb93e2365f0861918aabfe738cd))

## v0.1.55 (2021-03-01)


## v0.1.54 (2021-03-01)


## v0.1.53 (2021-03-01)


## v0.1.52 (2021-03-01)
### Feature
* **ring:** Update to latest ring_doorbell lib ([`a7295ca`](https://github.com/dominikkarall/fhempy/commit/a7295ca3fcfb3e6f62cdcc969556b79f8198f468))
* **tuya:** Update to latest tinytuya lib ([`0edc476`](https://github.com/dominikkarall/fhempy/commit/0edc476557bf54da6c7775b0101b68eb35894115))

## v0.1.51 (2021-02-17)
### Fix
* **fhempy:** Update cryptography ([`b154eb6`](https://github.com/dominikkarall/fhempy/commit/b154eb6b592cb672dbaabefc45b37e11ef304bce))

## v0.1.50 (2021-02-17)
### Fix
* **fhempy:** Fix cryptography installation ([`a7b4b6e`](https://github.com/dominikkarall/fhempy/commit/a7b4b6e5a5357f6b409656f4f79d99ce1b6154a3))

## v0.1.49 (2021-02-14)
### Feature
* **xiaomi_gateway3:** Update to latest version ([`9643837`](https://github.com/dominikkarall/fhempy/commit/96438373925c4c583dfbe4a9d8433fbc98aa678a))

### Fix
* **xiaomi_tokens:** Fix create miio device ([`f8e4352`](https://github.com/dominikkarall/fhempy/commit/f8e43525f62f00939f60d0ee30349246203682db))

## v0.1.48 (2021-02-02)
### Fix
* **xiaomi_tokens:** Fix device creation ([`ebbc3bb`](https://github.com/dominikkarall/fhempy/commit/ebbc3bb61f20fba4ff8d1eadd1af61017abe956e))

## v0.1.47 (2021-02-01)
### Fix
* **xiaomi_tokens:** Make readings country specific ([`efe1b7a`](https://github.com/dominikkarall/fhempy/commit/efe1b7a4f37d3530b2f92a906e45f202d67e6d21))

## v0.1.46 (2021-02-01)
### Fix
* **fhempy:** Raise error if pkg install fails ([`8b15dcd`](https://github.com/dominikkarall/fhempy/commit/8b15dcd19180451b45f3de4aa420938334f951d2))

## v0.1.45 (2021-01-31)
### Fix
* **xiaomi_gateway3:** Sort imports ([`89c14bc`](https://github.com/dominikkarall/fhempy/commit/89c14bc1477a91be51c86a80666f12e94430cb04))
* **googlecast:** Remove spotify_token dependency ([`ab8f872`](https://github.com/dominikkarall/fhempy/commit/ab8f8726158eb7037a62e98517a61b2760fbc47f))
* **xiaomi_gateway3:** Fix motion sensor reset ([`37222fc`](https://github.com/dominikkarall/fhempy/commit/37222fcd1d52c09cb97ba5943d939436c40d56a8))

## v0.1.44 (2021-01-30)
### Fix
* **fhempy:** Change logfile name to fhempy ([`2dc88df`](https://github.com/dominikkarall/fhempy/commit/2dc88df1177c69990926d5e55852656ee365f666))
* **xiaomi_gateway3:** Remove added_device reading ([`700e361`](https://github.com/dominikkarall/fhempy/commit/700e361417c9fc4ea634874b2f447396657c85fc))
* **fhempy:** Change log name to fhempy ([`ce8fac5`](https://github.com/dominikkarall/fhempy/commit/ce8fac5e3faa8fa8db360d787dc481288ba045f0))

## v0.1.43 (2021-01-30)


## v0.1.42 (2021-01-30)
### Feature
* **eq3bt:** Support wndOpnTime/Temp, eco/cmftTemp ([`107805f`](https://github.com/dominikkarall/fhempy/commit/107805fd5d85fde76a49e2fabe1994943d27a169))

## v0.1.41 (2021-01-30)


## v0.1.40 (2021-01-30)
### Feature
* **xiaomi_gateway3:** Support sensor_wleak.aq1 ([`bc8cf61`](https://github.com/dominikkarall/fhempy/commit/bc8cf6183bb4568b5f47b98e07669e3e8cda4f4e))

### Fix
* **fhempy:** Fix update ([`6f381c1`](https://github.com/dominikkarall/fhempy/commit/6f381c1be050f3ee26d4cbd236b2e2da447c581f))
* **object_detection:** Fix image detection ([`cc5c8de`](https://github.com/dominikkarall/fhempy/commit/cc5c8defa3457d5a60d812c062623654ed3b0e9e))
* **esphome:** Fix restart ([`be47a72`](https://github.com/dominikkarall/fhempy/commit/be47a7221fc1814c091992393652c4c767a8b203))

## v0.1.39 (2021-01-29)
### Feature
* **xiaomi_gateway3:** Support motion sensor ([`478db7a`](https://github.com/dominikkarall/fhempy/commit/478db7ad578ae6fef5a18066b2a4058fe561f745))
* **tuya:** Support another heating device ([`8843138`](https://github.com/dominikkarall/fhempy/commit/884313823231407a2155518cc01d04930246313c))

## v0.1.38 (2021-01-28)
### Fix
* **eq3bt:** Fix set temperatureOffset ([`429afcd`](https://github.com/dominikkarall/fhempy/commit/429afcd4f61f17b248dce60161d7418ec5770a54))

## v0.1.37 (2021-01-28)
### Fix
* **xiaomi_gateway3:** Add missing imports ([`b54aa4a`](https://github.com/dominikkarall/fhempy/commit/b54aa4a2529f1c7c23c3bfbb457c05790dcc0014))
* **fhempy:** Set IODev after CommandDefine ([`b1a1299`](https://github.com/dominikkarall/fhempy/commit/b1a12993b76cebe3949f510add7a7e1857b91869))

### Documentation
* Remove useless stuff ([`7401907`](https://github.com/dominikkarall/fhempy/commit/74019075190fb53b2cc7fdf6e4721360a698974e))

## v0.1.31 (2021-01-27)
### Feature
* **tuya:** Add keep_connected attr ([`b2c1ca4`](https://github.com/dominikkarall/fhempy/commit/b2c1ca47cf1b7adda9eb86731f21e0f755cf3dcd))

## v0.1.30 (2021-01-27)
### Fix
* **xiaomi_gateway3:** Remove unused imports ([`1758909`](https://github.com/dominikkarall/fhem_pythonbinding/commit/175890932f4efeeedba79ae6b2d1dfe81839abcc))

## v0.1.29 (2021-01-27)
### Fix
* **xiaomi_gateway3:** Add import time ([`7ef7a9e`](https://github.com/dominikkarall/fhem_pythonbinding/commit/7ef7a9ecabb2e8f765f6e1223bcaaaed365c6644))
* **xiaomi_gateway3:** Set last_update on update ([`146487d`](https://github.com/dominikkarall/fhem_pythonbinding/commit/146487daf69f9ed5219043c444fdfbac9f90021c))

## v0.1.28 (2021-01-27)
### Feature
* New reading pairing on/off ([`ee42b9c`](https://github.com/dominikkarall/fhem_pythonbinding/commit/ee42b9c1dc822993ee882e94be056b311f87bd8e))

## v0.1.27 (2021-01-27)
### Fix
* Pychromecast min version ([`8a58a53`](https://github.com/dominikkarall/fhem_pythonbinding/commit/8a58a5374c25ffcaf1f3c9a9f37b5ebb83272d96))
